@@ -1,10 +1,18 @@
 #ifndef _ASM_SIGCONTEXT_H
 #define _ASM_SIGCONTEXT_H
 
-#if defined(__i386__) || defined(__x86_64__)
+#include <sys/cdefs.h>
+
+__BEGIN_DECLS
+
+#if defined(__i386__)
 #include <asm/i386-sigcontext.h>
 #endif
 
+#if defined(__x86_64__)
+#include <asm/x86_64-sigcontext.h>
+#endif
+
 #ifdef __sparc__
 #include <asm/sparc-sigcontext.h>
 #endif
@@ -33,4 +41,10 @@
 #include <asm/ia64-sigcontext.h>
 #endif
 
+#ifdef __s390__
+#include <asm/s390-sigcontext.h>
+#endif
+
+__END_DECLS
+
 #endif
