@@ -5,6 +5,8 @@
 #include <sys/types.h>
 #include <limits.h>
 
+__BEGIN_DECLS
+
 struct dirent {
   long		d_ino;
   off_t		d_off;
@@ -41,18 +43,26 @@ long int telldir (DIR *__dirp) __THROW;
 int scandir(const char *dir, struct dirent ***namelist,
       int (*selection)(const struct dirent *),
       int (*compar)(const struct dirent **, const struct dirent **)) __THROW;
+int scandir64(const char *dir, struct dirent64 ***namelist,
+      int (*selection)(const struct dirent64 *),
+      int (*compar)(const struct dirent64 **, const struct dirent64 **)) __THROW;
 
 int alphasort(const struct dirent **a, const struct dirent **b) __THROW __attribute__((const));
+int alphasort64(const struct dirent64 **a, const struct dirent64 **b) __THROW __attribute__((const));
 
 #define MAXNAMLEN NAME_MAX
 
 #ifdef _BSD_SOURCE
-extern int dirfd(DIR *dirp) __THROW;
+extern int dirfd(DIR *dirp) __THROW __attribute_dontuse__;
 #endif
 
 #if defined _FILE_OFFSET_BITS && _FILE_OFFSET_BITS == 64
 #define dirent dirent64
 #define readdir readdir64
+#define scandir scandir64
+#define alphasort alphasort64
 #endif
 
+__END_DECLS
+
 #endif
