@@ -3,6 +3,8 @@
 
 #include <inttypes.h>
 
+__BEGIN_DECLS
+
 /* 32-bit ELF base types. */
 typedef uint32_t	Elf32_Addr;
 typedef uint16_t	Elf32_Half;
@@ -69,7 +71,7 @@ typedef int64_t		Elf64_Sxword;
 #define EM_SH		42	/* SuperH */
 #define EM_SPARCV9	43	/* SPARC v9 64-bit */
 #define EM_IA_64	50	/* HP/Intel IA-64 */
-#define EM_X8664	62	/* AMD x86-64 */
+#define EM_X86_64	62	/* AMD x86-64 */
 #define EM_CRIS		76	/* Axis Communications 32-bit embedded processor */
 
 /*
@@ -168,6 +170,12 @@ typedef int64_t		Elf64_Sxword;
 #define AT_PLATFORM	15	/* string identifying CPU for optimizations */
 #define AT_HWCAP	16	/* arch dependent hints at CPU capabilities */
 #define AT_CLKTCK	17	/* frequency at which times() increments */
+#define AT_FPUCW	18	/* Used FPU control word.  */
+#define AT_DCACHEBSIZE	19	/* Data cache block size.  */
+#define AT_ICACHEBSIZE	20	/* Instruction cache block size.  */
+#define AT_UCACHEBSIZE	21	/* Unified cache block size.  */
+#define AT_IGNOREPPC	22	/* Entry should be ignored */
+#define AT_SYSINFO	32	/* pointer to global system page */
 
 typedef struct dynamic{
   Elf32_Sword d_tag;
@@ -506,7 +514,37 @@ typedef struct {
 /* Additional symbol types for Thumb */
 #define STT_ARM_TFUNC		0xd
 
+/* AMD x86-64 relocations.  */
+#define R_X86_64_NONE		0	/* No reloc */
+#define R_X86_64_64		1	/* Direct 64 bit  */
+#define R_X86_64_PC32		2	/* PC relative 32 bit signed */
+#define R_X86_64_GOT32		3	/* 32 bit GOT entry */
+#define R_X86_64_PLT32		4	/* 32 bit PLT address */
+#define R_X86_64_COPY		5	/* Copy symbol at runtime */
+#define R_X86_64_GLOB_DAT	6	/* Create GOT entry */
+#define R_X86_64_JUMP_SLOT	7	/* Create PLT entry */
+#define R_X86_64_RELATIVE	8	/* Adjust by program base */
+#define R_X86_64_GOTPCREL	9	/* 32 bit signed PC relative
+					   offset to GOT */
+#define R_X86_64_32		10	/* Direct 32 bit zero extended */
+#define R_X86_64_32S		11	/* Direct 32 bit sign extended */
+#define R_X86_64_16		12	/* Direct 16 bit zero extended */
+#define R_X86_64_PC16		13	/* 16 bit sign extended pc relative */
+#define R_X86_64_8		14	/* Direct 8 bit sign extended  */
+#define R_X86_64_PC8		15	/* 8 bit sign extended pc relative */
+#define R_X86_64_DTPMOD64	16	/* ID of module containing symbol */
+#define R_X86_64_DTPOFF64	17	/* Offset in module's TLS block */
+#define R_X86_64_TPOFF64	18	/* Offset in initial TLS block */
+#define R_X86_64_TLSGD		19	/* 32 bit signed PC relative offset
+					   to two GOT entries for GD symbol */
+#define R_X86_64_TLSLD		20	/* 32 bit signed PC relative offset
+					   to two GOT entries for LD symbol */
+#define R_X86_64_DTPOFF32	21	/* Offset in TLS block */
+#define R_X86_64_GOTTPOFF	22	/* 32 bit signed PC relative offset
+					   to GOT entry for IE symbol */
+#define R_X86_64_TPOFF32	23	/* Offset in initial TLS block */
 
+#define R_X86_64_NUM		24
 
 typedef struct elf32_rel {
   Elf32_Addr	r_offset;
@@ -746,5 +784,6 @@ extern Elf64_Dyn _DYNAMIC [];
 
 #endif
 
+__END_DECLS
 
 #endif
