@@ -6,6 +6,8 @@
 #include <sys/types.h>
 #include <unistd.h>
 
+__BEGIN_DECLS
+
 #define F_LINUX_SPECIFIC_BASE	1024
 
 #if defined(__i386__) || defined(__s390__) || defined(__x86_64__) || defined(__ia64__)
@@ -549,16 +551,11 @@ struct flock64
 #endif
 
 extern int fcntl (int __fd, int __cmd, ...) __THROW;
-extern int lockf (int __fd, int __cmd, off_t __len) __THROW;
-extern int lockf64 (int __fd, int __cmd, off64_t __len) __THROW;
-
-#define F_ULOCK 0	/* Unlock a previously locked region.  */
-#define F_LOCK  1	/* Lock a region for exclusive use.  */
-#define F_TLOCK 2	/* Test and lock a region for exclusive use.  */
-#define F_TEST  3	/* Test a region for other processes locks.  */
 
 #if !defined(O_ASYNC) && defined(FASYNC)
 #define O_ASYNC FASYNC
 #endif
 
+__END_DECLS
+
 #endif
