@@ -3,6 +3,8 @@
 
 #include <sys/cdefs.h>
 
+__BEGIN_DECLS
+
 #define M_E		2.7182818284590452354	/* e */
 #define M_LOG2E		1.4426950408889634074	/* log_2 e */
 #define M_LOG10E	0.43429448190325182765	/* log_10 e */
@@ -93,4 +95,11 @@ double lgamma(double x);
 
 double rint(double x);
 
+double modf(double x, double * iptr);
+
+double frexp(double x, int *exp);
+double ldexp(double x, int exp);
+
+__END_DECLS
+
 #endif
