@@ -3,6 +3,8 @@
 
 #include <inttypes.h>
 
+__BEGIN_DECLS
+
 typedef int8_t int_least8_t;
 typedef int16_t int_least16_t;
 typedef int32_t int_least32_t;
@@ -27,4 +29,6 @@ typedef unsigned long long int uint_fast64_t;
 
 #include <endian.h>
 
+__END_DECLS
+
 #endif
