@@ -3,6 +3,8 @@
 
 #include <sys/cdefs.h>
 
+__BEGIN_DECLS
+
 #if defined(__i386__) || defined(__x86_64__) || defined(__ia64__)
 #include <sys/i386-ioctl.h>
 #elif defined(__alpha__)
@@ -29,4 +31,6 @@
 
 int ioctl(int d, int request, ...) __THROW;
 
+__END_DECLS
+
 #endif
