@@ -3,6 +3,8 @@
 
 #include <sys/ioctl.h>
 
+__BEGIN_DECLS
+
 /* structure for MTIOCTOP - mag tape op command */
 struct mtop {
   short int mt_op;	/* operations defined below */
@@ -337,4 +339,6 @@ struct mtftformat {
 #define DEFTAPE "/dev/tape/0"
 #endif
 
+__END_DECLS
+
 #endif
