@@ -3,6 +3,8 @@
 
 #include <sys/cdefs.h>
 
+__BEGIN_DECLS
+
 #define PTRACE_TRACEME		   0
 #define PTRACE_PEEKTEXT		   1
 #define PTRACE_PEEKDATA		   2
@@ -843,4 +845,6 @@ struct switch_stack {
 
 extern long int ptrace(int request, ...) __THROW;
 
+__END_DECLS
+
 #endif
