@@ -5,6 +5,8 @@
 #include <sys/types.h>
 #include <endian.h>
 
+__BEGIN_DECLS
+
 #if defined(__i386__)
 struct stat {
 	unsigned short	st_dev;
@@ -351,25 +353,34 @@ __extension__	unsigned long long	st_ino;
 #elif defined(__hppa__)
 
 struct stat {
-	unsigned long long st_dev;
-	unsigned short int _pad1;
-	unsigned long st_ino;
-	unsigned long st_mode;
-	unsigned long st_nlink;
-	unsigned long st_uid;
-	unsigned long st_gid;
-	unsigned long long st_rdev;
-	unsigned short int _pad2;
-	unsigned long st_size;
-	unsigned long st_blksize;
-	unsigned long st_blocks;
-	unsigned long st_atime;
-	unsigned long int unused1;
-	unsigned long st_mtime;
-	unsigned long int unused2;
-	unsigned long st_ctime;
-	unsigned long int unused3;
-	unsigned long long unused4;
+       unsigned long   st_dev;         /* dev_t is 32 bits on parisc */
+       unsigned long   st_ino;         /* 32 bits */
+       unsigned short  st_mode;        /* 16 bits */
+       unsigned short  st_nlink;       /* 16 bits */
+       unsigned short  st_reserved1;   /* old st_uid */
+       unsigned short  st_reserved2;   /* old st_gid */
+       unsigned long   st_rdev;
+       unsigned long   st_size;
+       unsigned long   st_atime;
+       unsigned long   st_spare1;
+       unsigned long   st_mtime;
+       unsigned long   st_spare2;
+       unsigned long   st_ctime;
+       unsigned long   st_spare3;
+       long            st_blksize;
+       long            st_blocks;
+       unsigned long   __unused1;      /* ACL stuff */
+       unsigned long   __unused2;      /* network */
+       unsigned long   __unused3;      /* network */
+       unsigned long   __unused4;      /* cnodes */
+       unsigned short  __unused5;      /* netsite */
+       short           st_fstype;
+       unsigned long   st_realdev;
+       unsigned short  st_basemode;
+       unsigned short  st_spareshort;
+       unsigned long   st_uid;
+       unsigned long   st_gid;
+       unsigned long   st_spare4[3];
 };
 
 struct stat64 {
@@ -384,7 +395,7 @@ struct stat64 {
 	unsigned long long st_rdev;
 	unsigned int __pad2;
 	unsigned long long st_size;
-	unsigned long long st_blksize;
+	unsigned long st_blksize;
 
 	unsigned long long st_blocks;
  	unsigned long st_atime;
@@ -513,4 +524,6 @@ extern int mkfifo (const char *__path, mode_t __mode) __THROW;
 #define S_IWRITE S_IWUSR
 #define S_IEXEC S_IXUSR
 
+__END_DECLS
+
 #endif
