@@ -36,11 +36,6 @@ int res_query(const char *dname, int class, int type, unsigned char *answer, int
       int j;	/* timeout count down */
       struct pollfd duh;
       struct timeval last,now;
-#ifdef WANT_IPV6_DNS
-      int tmpfd;	/* the warning gcc issues here is bogus */
-#else
-      duh.fd=__dns_fd;
-#endif
       i=0;
       duh.events=POLLIN;
       last.tv_sec=0;
@@ -48,6 +43,7 @@ int res_query(const char *dname, int class, int type, unsigned char *answer, int
 	gettimeofday(&now,0);
 	if (now.tv_sec-last.tv_sec>10) {
 #ifdef WANT_IPV6_DNS
+	  int tmpfd;
 	  struct sockaddr* s=(struct sockaddr*)&(_res.nsaddr_list[i]);
 	  if (s->sa_family==AF_INET6) {
 	    __dns_make_fd6();
@@ -60,6 +56,7 @@ int res_query(const char *dname, int class, int type, unsigned char *answer, int
 	  if (sendto(tmpfd,packet,size,0,s,sizeof(struct sockaddr_in6))==0)
 	    gettimeofday(&last,0);
 #else
+	  duh.fd=__dns_fd;
 	  if (sendto(__dns_fd,packet,size,0,(struct sockaddr*)&(_res.nsaddr_list[i]),sizeof(struct sockaddr))==0)
 	    gettimeofday(&last,0);
 #endif
@@ -69,11 +66,7 @@ int res_query(const char *dname, int class, int type, unsigned char *answer, int
 	if (poll(&duh,1,1000) == 1) {
 	  /* read and parse answer */
 	  unsigned char inpkg[1500];
-#ifdef WANT_IPV6_DNS
-	  int len=read(tmpfd,inpkg,1500);
-#else
-	  int len=read(__dns_fd,inpkg,1500);
-#endif
+	  int len=read(duh.fd,inpkg,1500);
 	  /* header, question, answer, authority, additional */
 	  if (inpkg[0]!=packet[0] || inpkg[1]!=packet[1]) continue;	/* wrong ID */
 	  if ((inpkg[2]&0xf9) != (_res.options&RES_RECURSE?0x81:0x80)) continue;	/* not answer */
