@@ -7,25 +7,17 @@
 
 /* will never return EINVAL ! */
 
-int pthread_mutex_unlock(pthread_mutex_t *mutex)
-{
-  _pthread_descr this;
-
-  __THREAD_INIT();
-
-  this = __thread_self();
-
-  if (this==mutex->owner) {
+int pthread_mutex_unlock(pthread_mutex_t*mutex) {
+  _pthread_descr this=__thread_self();
+  if (mutex->owner==this) {
     if (mutex->kind==PTHREAD_MUTEX_RECURSIVE_NP) {
       if (--(mutex->count)) return 0;
     }
-
     mutex->owner=0;
-    __pthread_unlock(&(mutex->lock));
+    UNLOCK(mutex);
   }
   else if (mutex->kind==PTHREAD_MUTEX_ERRORCHECK_NP) {
     return EPERM;
   }
-
   return 0;
 }
