@@ -5,32 +5,35 @@
 
 #include <stdlib.h>
 
-static pthread_mutex_t mutex_alloc = PTHREAD_MUTEX_INITIALIZER;
+static pthread_mutex_t mutex_alloc=PTHREAD_MUTEX_INITIALIZER;
 
 void free(void *ptr) {
-  __NO_ASYNC_CANCEL_BEGIN;
+  _pthread_descr this=__thread_self();
+  __NO_ASYNC_CANCEL_BEGIN_(this);
   pthread_mutex_lock(&mutex_alloc);
   __libc_free(ptr);
   pthread_mutex_unlock(&mutex_alloc);
-  __NO_ASYNC_CANCEL_END;
+  __NO_ASYNC_CANCEL_END_(this);
 }
 
 void *malloc(size_t size) {
+  _pthread_descr this=__thread_self();
   register void *ret;
-  __NO_ASYNC_CANCEL_BEGIN;
+  __NO_ASYNC_CANCEL_BEGIN_(this);
   pthread_mutex_lock(&mutex_alloc);
   ret=__libc_malloc(size);
   pthread_mutex_unlock(&mutex_alloc);
-  __NO_ASYNC_CANCEL_END;
+  __NO_ASYNC_CANCEL_END_(this);
   return ret;
 }
 
 void* realloc(void* ptr, size_t size) {
+  _pthread_descr this=__thread_self();
   register void *ret;
-  __NO_ASYNC_CANCEL_BEGIN;
+  __NO_ASYNC_CANCEL_BEGIN_(this);
   pthread_mutex_lock(&mutex_alloc);
   ret=__libc_realloc(ptr, size);
   pthread_mutex_unlock(&mutex_alloc);
-  __NO_ASYNC_CANCEL_END;
+  __NO_ASYNC_CANCEL_END_(this);
   return ret;
 }
