@@ -10,9 +10,9 @@ static FILE __stdin = {
   .next=0,
   .popen_kludge=0,
   .ungetbuf=0,
-  .ungotten=0
+  .ungotten=0,
 #ifdef WANT_THREAD_SAFE
-  , .m=PTHREAD_MUTEX_INITIALIZER
+  .m=PTHREAD_RECURSIVE_MUTEX_INITIALIZER_NP,
 #endif
 };
 
